@@ -43,10 +43,10 @@ struct _CamelImapMsg {
 	void (*free)(CamelImapStore *store, struct _CamelImapMsg *m);
 };
 
-CamelImapMsg *camel_imap_msg_new(void (*receive)(CamelImapStore *store, struct _CamelImapMsg *m),
+CamelImapMsg *camel_imap_msg_new (void (*receive)(CamelImapStore *store, struct _CamelImapMsg *m),
 				 void (*free)(CamelImapStore *store, struct _CamelImapMsg *m),
 				 gsize size);
-void camel_imap_msg_queue(CamelImapStore *store, CamelImapMsg *msg);
+void camel_imap_msg_queue (CamelImapStore *store, CamelImapMsg *msg);
 
 #endif
 
@@ -93,8 +93,8 @@ G_BEGIN_DECLS
 #define CAMEL_IMAP_STORE_CHECK_LSUB          (CAMEL_IMAP_STORE_ARG_CHECK_LSUB | CAMEL_ARG_BOO)
 
 /* CamelFolderInfo flags */
-#define CAMEL_IMAP_FOLDER_MARKED	     (1<<16)
-#define CAMEL_IMAP_FOLDER_UNMARKED	     (1<<17)
+#define CAMEL_IMAP_FOLDER_MARKED	     (1 << 16)
+#define CAMEL_IMAP_FOLDER_UNMARKED	     (1 << 17)
 
 typedef enum {
 	IMAP_LEVEL_UNKNOWN,
@@ -170,9 +170,9 @@ struct _CamelImapStoreClass {
 
 GType camel_imap_store_get_type (void);
 
-gboolean camel_imap_store_connected (CamelImapStore *store, CamelException *ex);
+gboolean camel_imap_store_connected (CamelImapStore *store, GError **error);
 
-gssize camel_imap_store_readline (CamelImapStore *store, gchar **dest, CamelException *ex);
+gssize camel_imap_store_readline (CamelImapStore *store, gchar **dest, GCancellable *cancellable, GError **error);
 
 G_END_DECLS
 
