@@ -455,6 +455,9 @@ pop3_folder_get_message_sync (CamelFolder *folder,
 		g_prefix_error (error, _("Cannot get message %s: "), uid);
 		g_object_unref (message);
 		message = NULL;
+	} else {
+		/* because the UID in the local store doesn't match with the UID in the pop3 store */
+		camel_medium_add_header (CAMEL_MEDIUM (message), "X-Evolution-POP3-UID", uid);
 	}
 done:
 	g_object_unref (stream);
@@ -551,7 +554,7 @@ pop3_folder_synchronize_sync (CamelFolder *folder,
 	pop3_folder = CAMEL_POP3_FOLDER (folder);
 	pop3_store = CAMEL_POP3_STORE (parent_store);
 
-	if (pop3_store->delete_after && !expunge) {
+	if (pop3_store->delete_after > 0 && !expunge) {
 		d(printf("%s(%d): pop3_store->delete_after = [%d], expunge=[%d]\n",
 			 __FILE__, __LINE__, pop3_store->delete_after, expunge));
 		camel_operation_push_message (
@@ -564,7 +567,7 @@ pop3_folder_synchronize_sync (CamelFolder *folder,
 		camel_operation_pop_message (cancellable);
 	}
 
-	if (!expunge) {
+	if (!expunge || (pop3_store->keep_on_server && !pop3_store->delete_expunged)) {
 		return TRUE;
 	}
 
@@ -720,7 +723,7 @@ camel_pop3_delete_old (CamelFolder *folder,
 	gint i;
 	CamelPOP3Store *pop3_store;
 	CamelMimeMessage *message;
-	time_t temp, message_time = 0;
+	time_t temp, message_time;
 
 	parent_store = camel_folder_get_parent_store (folder);
 
@@ -730,6 +733,7 @@ camel_pop3_delete_old (CamelFolder *folder,
 
 	d(printf("%s(%d): pop3_folder->uids->len=[%d]\n", __FILE__, __LINE__, pop3_folder->uids->len));
 	for (i = 0; i < pop3_folder->uids->len; i++) {
+		message_time = 0;
 		fi = pop3_folder->uids->pdata[i];
 
 		d(printf("%s(%d): fi->uid=[%s]\n", __FILE__, __LINE__, fi->uid));
@@ -792,4 +796,3 @@ camel_pop3_delete_old (CamelFolder *folder,
 
 	return 0;
 }
-
